@@ -344,11 +344,28 @@ def add_metadata(ds: xr.Dataset):
 def write_mappings(da: xr.DataArray, fn: str) -> None:
     """Write the mappings data to fortran"""
     with open(fn, "w") as f:
-        infos = da.attrs["numcells"], da.attrs["plasmacells"], da.attrs["other"]
+        at_keys = "numcells", "plasmacells", "other"
+        for key in at_keys:
+            assert key in da.attrs, (
+                "Writing requires to be the following attributes to be present:"
+                + ", ".join([f'"{k}"' for k in at_keys])
+                + ". Please ensure that they are copied over from the read file."
+            )
+        infos = tuple([da.attrs[k] for k in at_keys])
         f.write("%12d %11d %11d\n" % infos)
         _block_write(f, da.data.flatten(order="F") + 1, " %11d", 6)
 
 
+def read_raw(fn: str) -> xr.DataArray:
+    with open(fn) as f:
+        return xr.DataArray(f.read())
+
+
+def write_raw(da: xr.DataArray, fn: str) -> None:
+    with open(fn, "w") as f:
+        f.write(str(da.data))
+
+
 def read_locations(path: str, ds: xr.Dataset = None) -> xr.Dataset:
     """
     Read locations from folder path and add to dataset (if given).
@@ -836,6 +853,14 @@ def read_plates(dir: str) -> xr.Dataset:
     return ds
 
 
+def _dir_of(fn: str) -> str:
+    if os.path.isdir(fn):
+        return fn
+    if "/" in fn:
+        return fn.rsplit("/", 1)[0]
+    return "."
+
+
 def get_plates(dir: str, cache: bool = True) -> xr.Dataset:
     """
     Read the target fluxes from the EMC3_post processing routine
@@ -853,14 +878,8 @@ def get_plates(dir: str, cache: bool = True) -> xr.Dataset:
     xr.Dataset
         The target profiles
     """
-    if os.path.isdir(dir):
-        fn = "TARGET_PROFILES"
-    else:
-        if "/" in dir:
-            dir, fn = dir.rsplit("/", 1)
-        else:
-            fn = dir
-            dir = "."
+    dir = _dir_of(dir)
+
     if cache:
         try:
             if os.path.getmtime(dir + "/TARGET_PROFILES.nc") > os.path.getmtime(
@@ -1010,6 +1029,7 @@ def read_mapped(
     """
 
     if isinstance(mapping, xr.Dataset):
+        mapping = ensure_mapping(_dir_of(fn), mapping)
         mapping = mapping["_plasma_map"]
     if kinetic:
         max = np.max(mapping.data) + 1
@@ -1258,6 +1278,10 @@ def write_mapped(
     if skip_first is not None:
         for d in datas:
             if skip_first:
+                assert "print_before" in d.attrs, (
+                    'The "print_before" attribute is needed for writing. '
+                    "Please ensure it is preserved or copied from the read data."
+                )
                 assert d.attrs["print_before"] != ""
             else:
                 if "print_before" in d.attrs:
@@ -1404,6 +1428,26 @@ files: typing.Dict[str, typing.Dict[str, typing.Any]] = {
         kinetic=True,
         vars={"DENSITY_E_M_%d": dict()},
     ),
+    "fort.1": dict(
+        type="raw",
+        vars={"fort.1": dict(long_name="Geometry input file")},
+    ),
+    "fort.2": dict(
+        type="raw",
+        vars={
+            "fort.2": dict(
+                long_name="Plasma parameters, boundary and initial conditions input file"
+            )
+        },
+    ),
+    "fort.3": dict(
+        type="raw",
+        vars={"fort.3": dict(long_name="Control flow input file")},
+    ),
+    "fort.4": dict(
+        type="raw",
+        vars={"fort.4": dict(long_name="Neutrals input file for EIRENE")},
+    ),
     "fort.40": dict(
         type="mapped",
         vars={"fort.40_%d": dict()},
@@ -1653,47 +1697,43 @@ def read_fort_file(ds: xr.Dataset, fn: str, type: str = "mapped", **opts) -> xr.
     """
     assert files == _files_bak
     datas = None
+    vars = opts.pop("vars")
     if type == "mapping":
-        opts.pop("vars", False)
         ds["_plasma_map"] = read_mappings(fn, ds.R_bounds.data.shape[:3])
     elif type == "mapped":
-        vars = opts.pop("vars")
+        ds = ensure_mapping(_dir_of(fn), ds)
         datas = read_mapped(fn, ds["_plasma_map"], **opts, squeeze=False)
         opts = {}
     elif type == "full":
-        vars = opts.pop("vars")
         datas = [read_magnetic_field(fn, ds)]
     elif type == "plates_mag":
-        vars = opts.pop("vars")
         datas = [read_plates_mag(fn, ds)]
     elif type == "geom":
-        ds_ = read_locations(fn.rsplit("/", 1)[0])
-        _ = opts.pop("vars")
+        ds_ = read_locations(_dir_of(fn))
         ds = ds.assign_coords(ds_.coords)
         assert opts == {}, "Unexpected arguments: " + ", ".join(
             [f"{k}={v}" for k, v in opts.items()]
         )
     elif type == "info":
-        vars = opts.pop("vars")
         opts.pop("fmt")
         if "iteration" in ds.dims and "length" not in opts:
             opts["length"] = len(ds["iteration"])
         datas = read_info_file(fn, vars, **opts)
         opts = {}
     elif type == "surfaces":
-        vars = opts.pop("vars", None)
         ds_ = read_add_sf_n0(fn)
         ds = ds.assign_coords(ds_.coords)
         for k in ds_:
             ds[k] = ds_[k]
         datas = None
     elif type == "target_flux":
-        vars = opts.pop("vars", None)
         ds_ = get_plates(fn, False)
         ds = ds.assign_coords(ds_.coords)
         for k in ds_:
             ds[k] = ds_[k]
         datas = None
+    elif type == "raw":
+        datas = [read_raw(fn)]
     else:
         raise RuntimeError(f"Unexpected type {type}")
     assert files == _files_bak
@@ -1877,6 +1917,7 @@ def load_any(path: str, *args, **kwargs) -> xr.Dataset:
 
 def write_fort_file(ds, dir, fn, type="mapped", **opts):
     if type == "mapping":
+        assert list(opts["vars"].keys()) == ["_plasma_map"]
         write_mappings(ds["_plasma_map"], f"{dir}/{fn}")
     elif type == "mapped":
         write_mapped_nice(ds, dir, fn)
@@ -1888,12 +1929,19 @@ def write_fort_file(ds, dir, fn, type="mapped", **opts):
             write_magnetic_field(f"{dir}/{fn}", ds)
     elif type == "plates_mag":
         vars = opts.pop("vars")
+        assert list(vars.keys()) == ["PLATES_MAG"]
         write_plates_mag(f"{dir}/{fn}", ds)
     elif type == "info":
         write_info_file(f"{dir}/{fn}", ds)
     elif type == "geom":
         assert fn == "GRID_3D_DATA"
         write_locations(ds, f"{dir}/{fn}")
+    elif type == "raw":
+        vars = opts.pop("vars")
+        assert len(vars) == 1
+        write_raw(ds[list(vars.keys())[0]], f"{dir}/{fn}")
+    elif type in ["surfaces", "target_flux"]:
+        print(f"writing {fn} is not yet implemented. (PRs welcome)")
     else:
         raise RuntimeError(f"Unexpected type {type}")
 
